.. Warcat documentation master file, created by
   sphinx-quickstart on Wed Apr 10 11:53:54 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Warcat's documentation!
==================================

Contents:

.. toctree::
   :maxdepth: 2

   readme
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

